==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/autoscaling/v2beta2/HorizontalPodAutoscalerList.scala <==
package io.k8s.api.autoscaling.v2beta2

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects. */
final case class HorizontalPodAutoscalerList(
  items : Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("autoscaling", "HorizontalPodAutoscalerList", "v2beta2")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]) : HorizontalPodAutoscalerList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler*) : HorizontalPodAutoscalerList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler] => Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]) : HorizontalPodAutoscalerList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : HorizontalPodAutoscalerList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : HorizontalPodAutoscalerList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = HorizontalPodAutoscalerList.encoder[T].apply(this)
}

object HorizontalPodAutoscalerList {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList, T] = new Encoder[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList, T] {
        def apply(o: io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, HorizontalPodAutoscalerList] = new Decoder[T, HorizontalPodAutoscalerList] {
      def apply(t: T): Either[String, HorizontalPodAutoscalerList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield HorizontalPodAutoscalerList (
          items = items,
          metadata = metadata
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/autoscaling/v2beta2/HorizontalPodAutoscalerList.scala <==
package io.k8s.api.autoscaling.v2beta2

import dev.hnaderi.k8s._
import dev.hnaderi.k8s.utils._

/** HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects. */
final case class HorizontalPodAutoscalerList(
  items : Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler],
  metadata : Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
) extends KObject {
  protected val _resourceKind = ResourceKind("autoscaling", "HorizontalPodAutoscalerList", "v2beta2")


  /** Returns a new data with items set to new value */
  def withItems(value: Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]) : HorizontalPodAutoscalerList = copy(items = value)
  /** Appends new values to items */
  def addItems(newValues: io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler*) : HorizontalPodAutoscalerList = copy(items = items ++ newValues)
  /** transforms items to result of function */
  def mapItems(f: Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler] => Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]) : HorizontalPodAutoscalerList = copy(items = f(items))

  /** Returns a new data with metadata set to new value */
  def withMetadata(value: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : HorizontalPodAutoscalerList = copy(metadata = Some(value))
  /** if metadata has a value, transforms to the result of function*/
  def mapMetadata(f: io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta => io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta) : HorizontalPodAutoscalerList = copy(metadata = metadata.map(f))

  override def foldTo[T : Builder] : T = HorizontalPodAutoscalerList.encoder.apply(this)
}

object HorizontalPodAutoscalerList {

    implicit val encoder : Encoder[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList] = new Encoder[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList] {
        def apply[T : Builder](o: io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscalerList) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("items", o.items)
            .write("metadata", o.metadata)
            .write("kind", o.kind)
            .write("apiVersion", o.apiVersion)
            .build
        }
    }

    implicit val decoder: Decoder[HorizontalPodAutoscalerList] = new Decoder[HorizontalPodAutoscalerList] {
      def apply[T : Reader](t: T): Either[String, HorizontalPodAutoscalerList] = for {
          obj <- ObjectReader(t)
          items <- obj.read[Seq[io.k8s.api.autoscaling.v2beta2.HorizontalPodAutoscaler]]("items")
          metadata <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta]("metadata")
      } yield HorizontalPodAutoscalerList (
          items = items,
          metadata = metadata
        )
    }
}
